/*
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */


#include "IO/IOUtils.h"
#include "IO/AriaFileWriter.h"
#include "GUI/MainFrame.h"
#include "Midi/Sequence.h"

#include "main.h"

#include "wx/wx.h"
#include "wx/wfstream.h"
#include "wx/stdpaths.h"

#include <iostream>

namespace AriaMaestosa {
	
wxString to_wxString(int i)
{
	char buffer[10];
	sprintf (buffer, "%d", i);
	
	return wxString(buffer);
}

wxString to_wxString(float f)
{
	char buffer[15];
	sprintf (buffer, "%f", f);
	return wxString(buffer);
}

void assertFailed(wxString message)
{
	std::cerr << (wxString("Assertion failed : " ) + message) << std::endl;
	
	wxMessageBox( wxGetTranslation("Sorry, Aria Maestosa crashed. Please report these exact lines to the developers of the app:\n") + message +
				  wxGetTranslation("\n\nAfter you click OK, you will be offered to save your current work so that you do not lose your current data.") );
    
	wxString filepath;
	
save:
	filepath=wxFileSelector(wxGetTranslation("Select destination file"), wxT(""), wxGetTranslation("crash_recovery.aria"), wxT(".aria"), wxT("Aria Maestosa file|*.aria"), wxSAVE);
    
	if(!filepath.IsAscii())
	{
		wxMessageBox(wxGetTranslation("Invalid file name. (Sorry, accentuated characters are not supported)"));	
		goto save;
	}
	
    if(!filepath.IsEmpty())
	{
		
		if( wxFileExists(filepath) )
		{
			wxMessageBox( wxGetTranslation("The file already exists. Please choose another name."));
			goto save;
		}
		
        saveAriaFile(getMainFrame()->getCurrentSequence(), (char*)filepath.c_str());
		
    }// end if
	
	exit(0);

}

void writeData(wxString data, wxFileOutputStream& fileout)
{
	
	fileout.Write( data.c_str(), data.size());
	
}

wxString extract_filename(char* filepath)
{
	return wxString(filepath).AfterLast('/');
}

wxString extract_path(wxString str)
{
        if(str.GetChar(str.Length()) == '/') return str.BeforeLast('/').BeforeLast('/');
	else return str.BeforeLast('/');
}

wxString getResourcePrefix()
{
#if defined(__WXMAC__)
		return wxStandardPaths::Get().GetResourcesDir() + wxT("/");;
#elif defined(__WXGTK__)

                return extract_path( wxStandardPaths::Get().GetExecutablePath() ) + wxT("/Resources/");
#else

#warning "Resource Prefix undefined for your platform"
return wxT("./");

#endif
}

}
